pub struct PackageNames {
pub debian: &'static str,
pub fedora: &'static str,
pub arch: &'static str,
pub suse: &'static str,
pub generic: &'static str,
}Expand description
What one dependency is called on each family.
Fields
debian: &'static strfedora: &'static strarch: &'static strsuse: &'static strgeneric: &'static strProse for an unidentified distribution, where a package name would be a guess but “OpenSSL development headers” is still actionable.
Implementations
Sourceimpl PackageNames
impl PackageNames
Sourcepub const fn for_distro(&self, distro: LinuxDistro) -> Option<&'static str>
pub const fn for_distro(&self, distro: LinuxDistro) -> Option<&'static str>
The name for distro, or None when there is no name to give.